@@ -3,15 +3,15 @@ from dotenv import load_dotenv
 
 
 def main() -> None:
-    """
-    main entry point for the spam command line tool.
-    """
+
     load_dotenv()
-    cmd = parse_args()
-    cmd.func(cmd)
+    cli_args = parse_args()
+    command = cli_args.command(cli_args=cli_args)
+    command()
 
 
 if __name__ == "__main__":
+    print("foo")
     """
     This is here to allow execution by referencing the project directory instead of a .py file.
     """
