@@ -11,16 +11,13 @@ if program_name == "pytest":
     load_dotenv(".test.env", override=True)
 else:
     # load the environment file
-    load_dotenv()
+    env_path = Path.cwd() / ".env"
+    load_dotenv(env_path.as_posix())
 
 
 SUPERGLUE_S3_BUCKET = os.getenv("SUPERGLUE_S3_BUCKET")
 SUPERGLUE_IAM_ROLE = os.getenv("SUPERGLUE_IAM_ROLE")
 
-# for name validation
-SUPERGLUE_JOB_PREFIX = os.getenv("SUPERGLUE_JOB_PREFIX", "")
-SUPERGLUE_JOB_SUFFIX = os.getenv("SUPERGLUE_JOB_SUFFIX", "")
-
 # For simple account validation
 try:
     SUPERGLUE_AWS_ACCOUNT = int(os.getenv("SUPERGLUE_AWS_ACCOUNT"))
@@ -29,7 +26,6 @@ except TypeError:
 
 # keep this as we may want logging
 SUPERGLUE_LOGGER_DIR = Path(os.getenv("SUPERGLUE_LOGGER_FILE", "./logs"))
-# SUPERGLUE_LOGGER_DIR.mkdir(exist_ok=True, parents=True)
 
 
 def validate_environment() -> None:
